==> telegram_payment_bot-0.2.0.tar.gz: telegram_payment_bot-0.2.0/telegram_payment_bot/google_sheet_reader.py <==
# Copyright (c) 2021 Emanuele Bellocchia
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

#
# Imports
#
from typing import List, Union
from telegram_payment_bot.google_sheet_service import GoogleSheetService


#
# Classes
#

# Google sheet reader class
class GoogleSheetReader:
    # Constructor
    def __init__(self,
                 service: GoogleSheetService,
                 sheet_id: str) -> None:
        self.service = service
        self.sheet_id = sheet_id

    # Get range
    def GetRange(self,
                 range_cells: str) -> Union[List[str], List[List[str]]]:
        # Call the Sheets API
        sheet = self.service.GetHandle().spreadsheets()
        result = sheet.values().get(spreadsheetId=self.sheet_id,
                                    range=range_cells).execute()
        values = result.get("values", [])

        return [] if not values else values

==> telegram_payment_bot-0.3.3.tar.gz: telegram_payment_bot-0.3.3/telegram_payment_bot/google_sheet_reader.py <==
# Copyright (c) 2021 Emanuele Bellocchia
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

#
# Imports
#
from typing import Any, List
from telegram_payment_bot.google_sheet_service import GoogleSheetService


#
# Classes
#

# Google sheet reader class
class GoogleSheetReader:

    service: GoogleSheetService
    sheet_id: str

    # Constructor
    def __init__(self,
                 service: GoogleSheetService,
                 sheet_id: str) -> None:
        self.service = service
        self.sheet_id = sheet_id

    # Get range
    def GetRange(self,
                 range_cells: str) -> List[Any]:
        # Call the Sheets API
        sheet = self.service.GetHandle().spreadsheets()
        result = sheet.values().get(spreadsheetId=self.sheet_id,
                                    range=range_cells).execute()
        values = result.get("values", [])

        return [] if not values else values
